@@ -5,8 +5,7 @@ use Moose;
 
 extends qw/Verby::Config::Data::Mutable/;
 
-use strict;
-use warnings;
+our $VERSION = "0.03";
 
 use Log::Log4perl ();
 use Devel::Caller::Perl ();
